// 
//   Script to create a simple rectangular mesh
//

//   Create a model 

var m = new Model();

//   Parameters for mesh:
//      num_x         = number of elements in X-direction
//      num_y         = number of elements in Y-direction
//      size_x        = size of element in X-direction
//      size_y        = size of element in Y-direction
//      x0            = x-coordinate of bottom-left corner
//      y0            = y-coordinate of bottom-left corner
//      ID_node       = starting ID for nodes
//      ID_shell      = starting ID for shell elements
//      ID_part       = ID of part for shell elements
//      ID_node_next  = ID for next node to be created
//      ID_shell_next = ID for next shell to be created
   
var num_x = 30;
var num_y = 15;
var size_x = 10.0;
var size_y = 17.5;
var x0     = 0.0;
var y0     = 0.0;
var ID_node  = 1000;
var ID_shell = 1000;
var ID_part  = 100;

var ID_node_next = ID_node;
var ID_shell_next = ID_shell;

//   Create nodes
//   N.B we need num_x+1 in the X-direction, num_y+1 in the Y-direction
//
//   We will make nodes with IDs in this pattern (taking as an example
//     ID_node = 1000, num_x = 4 elements, num_y = 3 elements):
//
//     Y
//     |
//
//    1015----1016----1017----1018----1019
//      |       |       |       |       |
//    1010----1011----1012----1013----1014
//      |       |       |       |       |
//    1005----1006----1007----1008----1009
//      |       |       |       |       |
//    1000----1001----1002----1003----1004    -X
//

Message("Making nodes");

for (var iy=0; iy<num_y+1; iy++)
{
    for (var ix=0; ix<num_x+1; ix++)
    {
       var x = x0 + ix*size_x;
       var y = y0 + iy*size_y;
       var z = 0.0;
       var n = new Node(m, ID_node_next, x, y, z);
       ID_node_next++;
    }
}

//   Create shells
//
//   We will bear in mind the above pattern of node IDs when creating
//   the shell elements

Message("Making shells");

for (var iy=0; iy<num_y; iy++)
{
    for (var ix=0; ix<num_x; ix++)
    {
         var ix1 = ID_node + ix + (num_x+1)*iy;
	 var ix2 = ix1 + 1;
	 var ix3 = ix2 + num_x+1;
	 var ix4 = ix3 - 1;
         var s = new Shell(m, ID_shell_next, ID_part, ix1, ix2, ix3, ix4);
	 ID_shell_next++;
    }
}

//   Now draw the new model

m.UpdateGraphics();
View.Show(View.XY);
View.Li();
View.Ac();
